@@ -1,6 +1,7 @@
 import bw2data as bd
 from bw2io.utils import activity_hash
 import pandas as pd
+import importlib.resources as resources
 from copy import deepcopy
 import re
 
@@ -44,8 +45,8 @@ def bw_generate_new_biosphere_data_water(bio_act_list, new_bio_name):
 
 def bw_add_lcia_method_aware():
     flows_list = []
-
-    df = pd.read_csv(r'data/regionalization_setup/cf_aware_processed.csv',encoding="latin1", sep = ";")
+    with resources.open_text("ppplca.data.regionalization_setup","cf_aware_processed.csv") as f:
+        df = pd.read_csv(f, encoding="latin1", sep=";")
     df = df.map(lambda x: x.replace('__', ',') if isinstance(x, str) else x)
     df = df.drop("Column1",axis=1)
     df['Location'] = df['Location'].fillna('NA')
@@ -104,13 +105,15 @@ def bw_add_lcia_method_biodiversity():
     flows_occ_list = []
     flows_tra_list = []
 
-    df = pd.read_csv(r'data/regionalization_setup/cf_biodiversity_processed_new.csv', encoding="latin1", sep=";", index_col=0)
+    with resources.open_text("ppplca.data.regionalization_setup","cf_biodiversity_processed_new.csv") as f:
+        df = pd.read_csv(f, encoding="latin1", sep=";", index_col=0)
     df.index.name = None
     df = df.map(lambda x: x.replace('__', ',') if isinstance(x, str) else x)
     df['Location'] = df['Location'].fillna('NA')
 
     new_bio_db = bd.Database('biosphere luluc regionalized')
-    df_loc = pd.read_csv(r'data/regionalization_setup/Scherer_land_use_match.csv')
+    with resources.open_text("ppplca.data.regionalization_setup","Scherer_land_use_match.csv") as f:
+        df_loc = pd.read_csv(f)
     df_check = pd.DataFrame()
     for flow in new_bio_db:
         loc = flow.get('location')
@@ -195,9 +198,11 @@ def bw_generate_new_biosphere_data_pm(bio_act_list, new_bio_name):
 
 def bw_add_lcia_method_pm():
     flows_list = []
-    df = pd.read_csv(r'data/regionalization_setup/cf_pm_image_regions.csv', sep = ";")
+    with resources.open_text("ppplca.data.regionalization_setup","cf_pm_image_regions.csv") as f:
+        df = pd.read_csv(f, sep = ";")
     df = df.fillna(0)
-    eidb_310_to_image_conversion = pd.read_csv(r'data/regionalization_setup/Ecoinvent_310_to_IMAGE_conversion.csv', encoding="latin1",sep=";", keep_default_na=False)
+    with resources.open_text("ppplca.data.regionalization_setup","Ecoinvent_310_to_IMAGE_conversion.csv") as f:
+        eidb_310_to_image_conversion = pd.read_csv(f, encoding="latin1",sep=";", keep_default_na=False)
     eidb_310_to_image_conversion = eidb_310_to_image_conversion.map(lambda x: x.replace('__', ',') if isinstance(x, str) else x)
     new_bio_db = bd.Database(f'biosphere pm regionalized')
     for flow in new_bio_db:
@@ -224,7 +229,8 @@ def bw_add_lcia_method_pm():
     pm_method.write(flows_list)
 
 def bw_add_lcia_method_ipcc_ar6():
-    df = pd.read_excel(r'data_regionalized_impact_assessment/raw_data/ghg_cfs_ipcc_ar6.xlsx', engine='openpyxl', sheet_name='CFs')
+    with resources.open_binary("ppplca.data.regionalization_setup", "ghg_cfs_ipcc_ar6.xlsx") as f:
+        df = pd.read_excel(f, engine='openpyxl', sheet_name='CFs')
     for cf in ['GWP_100a', 'GTP_100a']:
         for cf_type in ['all', 'Biogenic', 'Fossil', 'LUC']:
             flows_list = []
